@@ -7,3 +7,5 @@ DISABLE_DISFLUENCIES_HEADER: str = 'DisableDisfluencies'
 ENABLE_PUNCTUATION_AND_CAPITALIZATION_HEADER: str = 'EnablePunctuationCapitalization'
 ENABLE_ENTITIES_RECOGNITION_HEADER: str = 'EnableEntitiesRecognition'
 ENABLE_NUMERALS_CONVERSION_HEADER: str = 'EnableNumeralsConversion'
+SPEAKERS_DIARIZATION_HEADER: str = 'SpeakersDiarization'
+SPEAKERS_NUMBER_HEADER: str = 'SpeakersNumber'
