@@ -30,6 +30,8 @@ class TranscriptionRequest:
                  enable_punctuation_capitalization: bool = False,
                  enable_entities_recognition: bool = False,
                  enable_numerals_conversion: bool = False,
+                 speakers_diarization: bool = False,
+                 speakers_number: Optional[int] = None,
                  **kwargs):
         assert file_uid is not None
         assert file_path is not None
@@ -50,6 +52,8 @@ class TranscriptionRequest:
         self.enable_punctuation_capitalization: bool = enable_punctuation_capitalization
         self.enable_entities_recognition: bool = enable_entities_recognition
         self.enable_numerals_conversion: bool = enable_numerals_conversion
+        self.speakers_diarization: bool = speakers_diarization
+        self.speakers_number: Optional[int] = speakers_number
 
         if isinstance(hotwords, list):
             self.hotwords = hotwords
@@ -64,6 +68,12 @@ class TranscriptionRequest:
         except Exception as e:
             logger.exception(f'Couldn\'t parse hotwords weight: {hotwords_weight}. %s', str(e))
 
+    def __str__(self):
+        return str(self.__dict__)
+
+    def __repr__(self):
+        return self.__str__()
+
 
 class TranscriptionResponse:
 
